@@ -1,12 +1,10 @@
-/******************************************************************************
-** $Id: rewrite.c,v 1.11 2012-01-29 19:28:01 gene Exp $
-**=============================================================================
+/*** rewrite.c ****************************************************************
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-2012 Gerd Neugebauer
+** (c) 1996-2014 Gerd Neugebauer
 ** 
 ** Net: gene@gerd-neugebauer.de
 ** 
@@ -209,7 +207,7 @@ static Rule new_rule(field,pattern,frame,flags,casep)/*			     */
     { OUT_OF_MEMORY("pattern"); }		   /*			     */
     RulePattern(new).allocated = 16;		   /*			     */
     RulePattern(new).syntax    = RE_SYNTAX_EMACS;  /*			     */
-    RulePattern(new).translate = (casep?trans_lower:NULL);/*		     */
+    RulePattern(new).translate = (casep?(char*)trans_lower:NULL);/*	     */
     RulePattern(new).fastmap   = NULL;		   /*			     */
     RulePattern(new).regs_allocated = REGS_FIXED;  /*			     */
 						   /*			     */
@@ -217,7 +215,11 @@ static Rule new_rule(field,pattern,frame,flags,casep)/*			     */
 				    strlen((char*)pattern),/*		     */
 				    &RulePattern(new) );/*	             */
 						   /*			     */
-    if ( msg ) { Err(msg); return NULL; }	   /*			     */
+    if ( msg ) {				   /*                        */
+      Err(msg);					   /*                        */
+      free(new);				   /*                        */
+      return NULL;				   /*                        */
+    }	   					   /*			     */
   }						   /*                        */
   else						   /*                        */
   {						   /*                        */
