@@ -1,12 +1,10 @@
-/******************************************************************************
-** $Id: tex_read.c,v 1.9 2012-01-28 06:44:26 gene Exp $
-**=============================================================================
+/*** tex_read.c ***************************************************************
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-2012 Gerd Neugebauer
+** (c) 1996-2014 Gerd Neugebauer
 ** 
 ** Net: gene@gerd-neugebauer.de
 **	    
@@ -423,7 +421,7 @@ static Token TeX_get_token(get_fct)		   /*			     */
 						   /*			     */
   for (;;)					   /*			     */
   {						   /*			     */
-    if (   tex_line == TokenNULL		   /*			     */
+   if (    tex_line == TokenNULL		   /*			     */
 	&& TeX_fill_line(get_fct) )		   /*			     */
     { return TokenNULL; }			   /*			     */
 						   /*			     */
@@ -661,7 +659,6 @@ void TeX_def(s)					   /*			     */
   Uchar *s;			   		   /*			     */
 { Uchar	*name,				   	   /*			     */
 	*ep   = NULL;			   	   /*			     */
-  char	c;				   	   /*			     */
   int	arity = 0;				   /*			     */
 						   /*			     */
   while( isspace(*s) ) s++;			   /*                        */
@@ -675,7 +672,7 @@ void TeX_def(s)					   /*			     */
   if ( ep == NULL ) ep = s;			   /*			     */
 						   /*			     */
   if ( *name == '\\' )				   /*                        */
-  {  						   /*                        */
+  { char c;				   	   /*			     */
     while (ep > name + 2 &&			   /*                        */
 	   (*(ep-1)  == ' ' || *(ep-1) =='\t'))	   /*                        */
     { ep--; }					   /*                        */
@@ -829,7 +826,7 @@ void TeX_close()				   /*			     */
 ** Purpose:	Check if *tp contains a token.
 **		Otherwise try to get one and store it there.
 ** Arguments:
-**	tp
+**	tp	the pointer to the token
 ** Returns:	
 **___________________________________________________			     */
 static int fill_token(tp)			   /*			     */
@@ -861,7 +858,6 @@ int TeX_read(cp,sp)				   /*			     */
   static Token	old_t = TokenNULL;		   /*			     */
   static Token	arg[10];			   /*			     */
   Token		t2,tp;				   /*			     */
-  MacDef	mac;				   /*			     */
   int		i,d;				   /*			     */
 						   /*			     */
   EnsureInit;					   /*			     */
@@ -869,8 +865,9 @@ int TeX_read(cp,sp)				   /*			     */
 						   /*			     */
   while ( fill_token(&t) )			   /* One token left or	     */
   {						   /*  I got a new one.	     */
-    if ( (mac=active[TokenChar(t)]) != MacDefNULL )/* Is it active?          */
-    { UnlinkAndFreeToken(t,t2);			   /* Delete active token    */
+    MacDef mac = active[TokenChar(t)];	   	   /*			     */
+    if ( mac != MacDefNULL )			   /* Is it active?          */
+    { UnlinkAndFreeToken(t, t2);		   /* Delete active token    */
     }						   /*                        */
     else if ( TokenChar(t) == CHAR_ESCAPE &&	   /*                        */
 	      (mac=find_macro(TokenSeq(t),macro))  /*  or an undefined	     */
@@ -887,8 +884,7 @@ int TeX_read(cp,sp)				   /*			     */
       return 1;					   /*			     */
     }						   /*			     */
 						   /*			     */
-						   /*			     */
-    for ( i=1; i<=MacroArity(mac); ++i )	   /* Fill the argument	     */
+    for ( i = 1; i <= MacroArity(mac); ++i )	   /* Fill the argument	     */
     {						   /*  vector		     */
       if ( !fill_token(&t) )			   /*			     */
       { arg[i] = TokenNULL;			   /* Not enough tokens	     */
